#
# spec file for package libGLw
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define use_motif 1
%define libversion 1

Name:           libGLw
URL:            http://www.mesa3d.org
Provides:       Mesa:%{_libdir}/libGLw.so.1
Version:        8.0.0
Release:        7.9
%define date	20130123
%define sha1	c4f7cdf
Summary:        Xt/Motif OpenGL drawing area widget library
License:        MIT
Group:          Development/Libraries/C and C++
Source:         glw-%{version}_%{date}_%{sha1}.tar.bz2
Source1:        baselibs.conf
Patch1:         n_Use-newly-introduced-GLAPIVAR-for-variables.patch
# Needs to be set in buildservice project, see 'osc meta prjconf X11:XOrg'
# for an example
%if 0%{?use_motif} != 0
%define lname_m	libGLwM%{libversion}
BuildRequires:  openmotif-devel
%endif
%define lname	libGLw%{libversion}
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xt)

%description
Xt/Motif OpenGL drawing area widget library shipped by the Mesa Project.

%package -n %lname
Summary:        Xt OpenGL drawing area widget library
# O/P added in 12.2
Group:          System/Libraries
Provides:       GLw%{libversion} = %version-%release
Provides:       MesaGLw = %version-%release
Obsoletes:      MesaGLw < %version-%release
Conflicts:      libGLwM%{libversion}

%description -n %lname
Xt OpenGL drawing area widget library shipped by the Mesa Project.

%package devel
Requires:       GLw%{libversion} = %version
Requires:       GLw%{libversion} = %version-%release
Requires:       pkgconfig(gl)
Summary:        Includes and more to develop MesaGLw applications
Group:          Development/Libraries/C and C++

%description devel
This package contains all necessary include files needed
to develop applications that require these.

%package -n %lname_m
Summary:        Motif OpenGL drawing area widget library
# O/P added in 12.2
Group:          System/Libraries
Provides:       GLw%{libversion} = %version-%release
Provides:       MesaGLw = %version-%release
Obsoletes:      MesaGLw < %version-%release
Conflicts:      libGLw%{libversion}
Requires:       openmotif

%description -n %lname_m
Motif OpenGL drawing area widget library shipped by the Mesa Project.

%prep
%autosetup -p1 -n glw-%{version}

%build
mkdir build-GLw; cd build-GLw; ln -sf ../configure
%{configure} --srcdir=../
%make_build OPT_FLAGS="%{optflags}"
%if 0%{?use_motif}
mkdir ../build-GLwM; cd ../build-GLwM; ln -sf ../configure
%{configure} --srcdir=../ --enable-motif
%make_build OPT_FLAGS="%{optflags}"
%endif

%install
%if 0%{?use_motif} != 0
cd build-GLwM
%make_install
i=$(echo %{buildroot}/%{_libdir}/libGLw.so.*.*.*); mv $i ${i/libGLw.so/libGLwM.so};
cd ..
%endif
cd build-GLw
%make_install
i=$(echo %{buildroot}/%{_libdir}/libGLw.so.*.*.*); mv $i ${i/libGLw.so/libGLwXT.so};
rm -f %{buildroot}/%{_libdir}/libGLw.la %{buildroot}/%{_libdir}/libGLw.a %{buildroot}/%{_libdir}/libGLw.so.? %{buildroot}/%{_libdir}/libGLw.so

%post -n %lname -p /sbin/ldconfig

%postun -n %lname -p /sbin/ldconfig

%files -n %lname
%doc README
%{_libdir}/libGLwXT.so.1.*

%files devel
/usr/include/GL
%{_libdir}/pkgconfig/glw.pc

%triggerin -n libGLw-devel -- %lname
ln -snf libGLw.so.1 %{_libdir}/libGLw.so

%triggerin -n libGLw-devel -- %lname_m
ln -snf libGLw.so.1 %{_libdir}/libGLw.so

%preun devel
 [ $1 -eq 0 ] && rm -f %{_libdir}/libGLw.so || true

%post -n %lname_m -p /sbin/ldconfig

%postun -n %lname_m -p /sbin/ldconfig

%if 0%{?use_motif}
%files -n %lname_m
%doc README
%{_libdir}/libGLwM.so.1.*

%endif

%changelog
* Fri Jun  3 2022 Jan Engelhardt <jengelh@inai.de>
- Trim old specfile constructs
- Trim baselibs.conf; no other package in openSUSE:Factory
  buildrequires it and the case for compat should at most exist
  with 32-bit binaries.
* Mon Oct  4 2021 Stefan Dirsch <sndirsch@suse.com>
- fix libGLw.so symlink of devel package (bsc#1191122)
* Thu Jul 29 2021 Stefan Dirsch <sndirsch@suse.com>
- includes everything needed for ECO to enable Motif support in
  SLE12-SP5 (jira#SLE-15018)
* Fri Feb 23 2018 sndirsch@suse.com
- n_Use-newly-introduced-GLAPIVAR-for-variables.patch
  * moved bits from Mesa's n_Define-GLAPIVAR-separate-from-GLAPI.patch
    into this one (boo#1082297)
- always build with Motif support
* Mon May 29 2017 sndirsch@suse.com
- includes everything needed for missing sle issue entries:
  fate #315643-315645, 319159-319161, 319618 (bsc#1041368)
* Sat Mar 19 2016 eich@suse.com
- Consolidate building of libGLw for Xt and Motif.
* Wed Mar 16 2016 eich@suse.com
- n_Use-newly-introduced-GLAPIVAR-for-variables.patch
  Use newly introduced GLAPIVAR instead of GLAPI for
  variable declarations. This adds an 'extern' in cases
  where GLAPI doesn't have one and avoids a variable
  declarartion to become a definition (bsc#970725).
* Fri Jan 30 2015 sndirsch@suse.com
- updated to current git 8.0.0_20130123_c4f7cdf; since
  1.0.0_20120320_4d1acb3 this is just a version bump to 8.0.0
  and one typo fix (git commit c4f7cdf)
- specfile cleanup
* Mon Oct 27 2014 sndirsch@suse.com
- fixed buildrequires: pkgconfig(dri) -> pkgconfig(gl)
- added baselibs.conf as source to specfile
* Fri Sep 21 2012 sndirsch@suse.com
- fixed BuildRequires
* Wed Sep 19 2012 sndirsch@suse.com
- fixed build on openSUSE 12.2
* Tue Jun  5 2012 sndirsch@suse.com
- enable Motif support if %%use_motif is set (currently done in
  X11:XOrg, but likely planned also for openSUSE:Factory:NonFree
  project)
* Mon Jun  4 2012 sndirsch@suse.com
- added generation of biarch packages
* Wed May 30 2012 crrodriguez@opensuse.org
- Fix -devel package requires, it needs pkgconfig(gl)
- Fix buildrequires to require explicitely all needed libraries.
* Thu May 10 2012 sndirsch@suse.com
- disable motif support in light of recent findings of the
  legal-team
- switched to minimal pkgconfig buildrequires
* Fri Mar 23 2012 eich@suse.com
- Change file naming sceme to what's expected for libraries:
  Now the packages are named after the library, without any Mesa*
  in their names.
* Thu Mar 22 2012 eich@suse.com
- Replace Mesa package as source of libGLw by stand alone glw package
  created by the Mesa Project:
  Delete: MesaLib-7.10.2.tar.bz2
  Add: glw-1.0.0_20120320_4d1acb3.tar.bz2
  NOTE: Since there is no release of glw yet a tarball generated from
  the source repository is used. This contains the sources of
  the last version in MesaLib-7.10.2 plus a few bug fixes.
* Tue Feb 21 2012 sndirsch@suse.com
- No particular reason for having conflicts with other providers
  of libGLw1, since there are no other providers of this lib and
  probably will never be
* Mon Feb 20 2012 sndirsch@suse.com
- use pkgconfig(...) capabilities for BuildRequires
* Mon Feb 13 2012 jengelh@medozas.de
- Remove redundant tags/sections from specfile
- Try shlib policy on the package
* Sun Oct  2 2011 mhrusecky@suse.cz
- configure -> ./configure (fixes build)
* Mon Jun  6 2011 eich@suse.de
- remove GLw-motif.diff. Instead resolve in spec file.
* Sat Sep  4 2010 sndirsch@novell.com
- update to Mesa 7.8.2
* Sat Apr 10 2010 sndirsch@suse.de
- update to Mesa 7.8.1 sources
- legal check no longer necessary
* Tue Mar  3 2009 sndirsch@suse.de
- update to Mesa 7.3 sources
* Sat Sep 20 2008 sndirsch@suse.de
- update to Mesa 7.2 sources
* Wed Aug 27 2008 sndirsch@suse.de
- update to Mesa release 7.1
* Sat Apr  5 2008 sndirsch@suse.de
- update to Mesa bugfix release 7.0.3 (final)
* Wed Apr  2 2008 sndirsch@suse.de
- update to Mesa bugfix release 7.0.3 RC3
* Fri Feb 22 2008 sndirsch@suse.de
- update to Mesa bugfix release 7.0.3 RC2
  * Fixed GLX indirect vertex array rendering bug (14197)
  * Fixed crash when deleting framebuffer objects (bugs 13507,
    14293)
  * User-defined clip planes enabled for R300 (bug 9871)
  * Fixed glBindTexture() crash upon bad target (bug 14514)
  * Fixed potential crash in glDrawPixels(GL_DEPTH_COMPONENT) (bug
    13915)
  * Bad strings given to glProgramStringARB() didn't generate
    GL_INVALID_OPERATION
  * Fixed minor point rasterization regression (bug 11016)
* Wed Jan 23 2008 sndirsch@suse.de
- update to Mesa bugfix release 7.0.3 RC1
  * Added missing glw.pc.in file to release tarball
  * Fix GLUT/Fortran issues
  * GLSL gl_FrontLightModelProduct.sceneColor variable wasn't
    defined
  * Fix crash upon GLSL variable array indexes (not yet supported)
  * Two-sided stencil test didn't work in software rendering
  * Fix two-sided lighting bugs/crashes (bug 13368)
  * GLSL gl_FrontFacing didn't work properly
  * glGetActiveUniform returned incorrect sizes (bug 13751)
  * Fix several bugs relating to uniforms and attributes in GLSL
    API (Bruce Merry, bug 13753)
  * glTexImage3D(GL_PROXY_TEXTURE_3D) mis-set teximage depth field
* Tue Jan  1 2008 crrodriguez@suse.de
- fix library-without-ldconfig-* error
* Sat Nov 10 2007 sndirsch@suse.de
- updated to Mesa 7.0.2 (final)
* Wed Oct 31 2007 sndirsch@suse.de
- updated to Mesa 7.0.2 RC1
* Sat Aug  4 2007 sndirsch@suse.de
- updated to bugfix release 7.0
* Sat Jun 23 2007 sndirsch@suse.de
- updated to final release 7.0
* Thu Jun 21 2007 sndirsch@suse.de
- updated Mesa to release 7.0 RC1
  * Mesa 7.0 is a stable, follow-on release to Mesa 6.5.3. The only
    difference is bug fixes. The major version number bump is due
    to OpenGL 2.1 API support.
* Mon Apr 30 2007 sndirsch@suse.de
- updated to Mesa 6.5.3
* Fri Apr 27 2007 sndirsch@suse.de
- back to Mesa 6.5.2 (Bug #269155/269042)
* Wed Apr 25 2007 sndirsch@suse.de
- 4th RC ready
  * This fixes some breakage in RC3.
* Tue Apr 24 2007 sndirsch@suse.de
- 3rd release candidate
  * updated Windows/VC8 project files.
* Sun Apr 22 2007 sndirsch@suse.de
- updated to Mesa 6.5.3rc2
  * a number of bug fixes since the first RC
* Sat Apr 21 2007 sndirsch@suse.de
- updated to Mesa 6.5.3rc1
* Sat Dec  2 2006 sndirsch@suse.de
- updated to Mesa 6.5.2
* Mon Sep 18 2006 sndirsch@suse.de
- updated to Mesa 6.5.1
* Sat Sep  9 2006 sndirsch@suse.de
- removed two source files with imcompatible license from Mesa
  tarball (Bug #204110)
- added a check to specfile to make sure that these will not be
  reintroduced with the next Mesa update again (Bug #204110)
* Sat Aug 19 2006 sndirsch@suse.de
- fixed build for X.Org < 7
- .so/.so.1 files should be symlinks!
* Thu Aug 17 2006 sndirsch@suse.de
- created package
